@@ -1,7 +1,5 @@
 package Image::Synchronize::Timerange;
 
-use v5.10.0;
-
 =head1 NAME
 
 Image::Synchronize::Timerange - a timestamp range class
@@ -558,7 +556,7 @@ sub add {
   return $result;
 }
 
-=head2 stringify
+=stringify
 
   $text = $r->stringify;
   $text = "$r";
